@@ -10,10 +10,10 @@ from dagster import (
     Nothing,
     OutputDefinition,
     Permissive,
-    check,
-    op,
-    solid,
 )
+from dagster import _check as check
+from dagster import op
+from dagster._legacy import solid
 
 from .utils import execute, execute_script_file
 
