@@ -22,8 +22,8 @@ import os
 import signal
 from subprocess import PIPE, STDOUT, Popen
 
-from dagster import check
-from dagster.utils import safe_tempfile_path
+import dagster._check as check
+from dagster._utils import safe_tempfile_path
 
 OUTPUT_LOGGING_OPTIONS = ["STREAM", "BUFFER", "NONE"]
 
